"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeVerification = void 0;
var feathers_hooks_common_1 = require("feathers-hooks-common");
/**
 * Sanitize users. After-hook for '/users' service.
 */
function removeVerification(ifReturnTokens) {
    return function (context) {
        (0, feathers_hooks_common_1.checkContext)(context, 'after');
        // Retrieve the items from the hook
        var items = (0, feathers_hooks_common_1.getItems)(context);
        if (!items)
            return;
        var isArray = Array.isArray(items);
        var users = (isArray ? items : [items]);
        users.forEach(function (user) {
            if (!('isVerified' in user) && context.method === 'create') {
                /* eslint-disable no-console */
                console.warn('Property isVerified not found in user properties. (removeVerification)');
                console.warn("Have you added authManagement's properties to your model? (Refer to README)");
                console.warn('Have you added the addVerification hook on users::create?');
                /* eslint-enable */
            }
            if (context.params.provider && user) {
                // noop if initiated by server
                delete user.verifyExpires;
                delete user.resetExpires;
                delete user.verifyChanges;
                if (!ifReturnTokens) {
                    delete user.verifyToken;
                    delete user.verifyShortToken;
                    delete user.resetToken;
                    delete user.resetShortToken;
                }
            }
        });
        // Replace the items within the hook
        (0, feathers_hooks_common_1.replaceItems)(context, isArray ? users : users[0]);
        return context;
    };
}
exports.removeVerification = removeVerification;
